<?php

namespace Drupal\orange_dam;

/**
 * Manages preparing content for migrations and building the migration queues.
 */
interface OrangeDamMigrationDataManagerInterface {

  /**
   * Queue an item for further processing in a migration.
   *
   * @param \Drupal\orange_dam\OrangeDamItemInterface $item
   *   The Orange DAM item.
   */
  public function queueMigrationItem(OrangeDamItemInterface $item): void;

  /**
   * Runs Orange DAM related migrations.
   *
   * @param string|null $limit
   *   The number of items to limit each migration run to.
   * @param array|null $idlist
   *   An array of source ID values to limit the migration to.
   * @param array $migration_ids
   *   An array of migration ID values to run. Defaults to all migrations.
   * @param bool $disable_duplicate_check
   *   Set if duplicates checking should be disabled.
   */
  public function runMigrations(string $limit = '', ?array $idlist = [], array $migration_ids = [], bool $disable_duplicate_check = TRUE);

  /**
   * Get the list of Orange DAM migrations.
   *
   * @return \Drupal\migrate\Plugin\MigrationInterface[]
   *   The Orange DAM migrations.
   */
  public function getMigrations(): array;

}
